Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FiringAlertsPoll ¶
func FiringAlertsPoll(client *splunk.SplunkClient, ddKeptn *keptnv2.Keptn, keptnOptions keptn.KeptnOpts, envConfig utils.EnvConfig)
FiringAlertsPoll will handle all requests for '/health' and '/ready'
func ProcessAndForwardAlertEvent ¶
func ProcessAndForwardAlertEvent(triggeredInstance splunkalerts.EntryItem, logger *keptn.Logger, client *splunk.SplunkClient, ddKeptn *keptnv2.Keptn, keptnOptions keptn.KeptnOpts, envConfig utils.EnvConfig) error
ProcessAndForwardAlertEvent reads the payload from the request and sends a valid Cloud event to the keptn event broker
Types ¶
type RemediationTriggeredEventData ¶
type RemediationTriggeredEventData struct {
keptnv2.EventData
// Problem contains details about the problem
Problem keptncommons.ProblemEventData `json:"problem"`
// Deployment contains the current deployment, that is inferred from the alert details
Deployment keptnv2.DeploymentFinishedData `json:"deployment"`
}
Click to show internal directories.
Click to hide internal directories.